@@ -1,23 +1,8 @@
-/***************************************************************************
- *   KSystemLog, a system log viewer tool                                  *
- *   Copyright (C) 2007 by Nicolas Ternisien                               *
- *   nicolas.ternisien@gmail.com                                           *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Nicolas Ternisien <nicolas.ternisien@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "logViewModel.h"
 
@@ -28,7 +13,7 @@
 #include "logViewWidget.h"
 #include "logViewWidgetItem.h"
 
-#include "logging.h"
+#include "ksystemlog_debug.h"
 
 #include "ksystemlogConfig.h"
 
@@ -93,7 +78,7 @@ void LogViewModel::startingMultipleInsertions()
     mConcurrentMultipleInsertions++;
 
     if (hasLocked) {
-        logDebug() << "Starting multiple insertions...";
+        qCDebug(KSYSTEMLOG) << "Starting multiple insertions...";
 
         Q_EMIT processingMultipleInsertions(true);
 
@@ -110,7 +95,7 @@ void LogViewModel::endingMultipleInsertions(Analyzer::ReadingMode readingMode, i
     mConcurrentMultipleInsertions--;
 
     if (lockMultipleInsertions()) {
-        logDebug() << "Ending multiple insertions...";
+        qCDebug(KSYSTEMLOG) << "Ending multiple insertions...";
 
         // Scroll to the newest item if some lines have been added
         if (insertedLogLineCount > 0) {
@@ -121,7 +106,7 @@ void LogViewModel::endingMultipleInsertions(Analyzer::ReadingMode readingMode, i
             mLogViewWidget->resizeColumns();
         }
 
-        logDebug() << "Enabling log view widget refresh...";
+        qCDebug(KSYSTEMLOG) << "Enabling log view widget refresh...";
         mLogViewWidget->setUpdatesEnabled(true);
 
         Q_EMIT processingMultipleInsertions(false);
@@ -132,13 +117,10 @@ bool LogViewModel::lockMultipleInsertions()
 {
     if (mConcurrentMultipleInsertions == 0) {
         return true;
-    }
-
-    // Debug messages
-    if (mConcurrentMultipleInsertions > 0) {
-        logDebug() << "Existing multiple insertions request is still active";
-    } else if (mConcurrentMultipleInsertions < 0) {
-        logCritical() << "Existing multiple insertions forgot to call this method";
+    } else if (mConcurrentMultipleInsertions > 0) {
+        qCDebug(KSYSTEMLOG) << "Existing multiple insertions request is still active";
+    } else {
+        qCCritical(KSYSTEMLOG) << "Existing multiple insertions forgot to call this method";
     }
 
     return false;
@@ -177,14 +159,14 @@ bool LogViewModel::isNewer(LogLine *newLine) const
 
 void LogViewModel::removeOldestLogLine()
 {
-    // logDebug() << "Removing oldest log line";
+    // qCDebug(KSYSTEMLOG) << "Removing oldest log line";
 
     if (isEmpty()) {
         return;
     }
 
     if (!mOldestItem) {
-        logWarning() << "Oldest item is null";
+        qCWarning(KSYSTEMLOG) << "Oldest item is null";
         return;
     }
 
@@ -245,7 +227,7 @@ bool LogViewModel::insertNewLogLine(LogLine *line)
         return true;
     }
 
-    // logDebug() << "Do not insert an old line : " << line->logItems();
+    // qCDebug(KSYSTEMLOG) << "Do not insert an old line : " << line->logItems();
 
     return false;
 }
